summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldermbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldermbox.h')
-rw-r--r--kmail/kmfoldermbox.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kmail/kmfoldermbox.h b/kmail/kmfoldermbox.h
index 7c48324e9..cf8871372 100644
--- a/kmail/kmfoldermbox.h
+++ b/kmail/kmfoldermbox.h
@@ -39,7 +39,7 @@ using KMail::AttachmentStrategy;
*
* Accounts:
* The accounts (of KMail) that are fed into the folder are
- * represented as the children of the folder. They are only stored here
+ * represented as the tqchildren of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
@@ -47,12 +47,13 @@ using KMail::AttachmentStrategy;
class KMFolderMbox : public KMFolderIndex
{
Q_OBJECT
+ TQ_OBJECT
friend class ::KMail::MboxJob;
public:
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderMbox(KMFolder* folder, const char* name=0);
virtual ~KMFolderMbox();
@@ -109,7 +110,7 @@ public:
static TQByteArray escapeFrom( const DwString & str );
- virtual IndexStatus indexStatus();
+ virtual IndextqStatus indextqStatus();
/** reimp */
virtual TQ_INT64 doFolderSize() const;